import React from 'react';
import { TextStyle, ViewStyle } from 'react-native';
import { RadioButtonProps } from 'react-native-radio-buttons-group/lib/types';

type FileUploaded = {
    original_name: string;
    job_file_id: string;
    file_url: string;
};

type FieldCommonType = {
    label: string;
    name: string;
    onChange?: (newValue: string) => void;
    initialValue?: string;
    required?: boolean;
};
type TitleType = {
    type: "title";
    name: string;
    labelIsHtml?: boolean;
    label: string;
    initialValue?: string;
    required?: boolean;
};
type SignatureValueType = {
    whoSigned: string | null;
    base64_image: string | null;
};
type SignatureFieldType = FieldCommonType & {
    type: "signature";
    multiple?: boolean;
    disabledInput?: boolean;
    initialValue?: SignatureValueType[];
    optionWhoSign?: string[];
};
type OptionMultipleChoiceType = {
    label: string;
    styleLabel?: TextStyle;
    style?: ViewStyle;
    disabled?: boolean;
    checked: boolean;
};
type MultipleChoiceType = FieldCommonType & {
    type: "multiple_choice";
    options: OptionMultipleChoiceType[];
};
type SingleChoiceType = FieldCommonType & {
    type: "single_choice";
    options: RadioButtonProps[];
};
type InputTextNumberType = FieldCommonType & {
    type: "number" | "text";
    placeholder?: string;
};
type RequiresTextAnswersType = {
    item_name: string;
    value: string;
};
type InputTextAnswerType = FieldCommonType & {
    type: "text_answer";
    placeholder?: string;
    requires?: RequiresTextAnswersType;
};
type FileInputType = FieldCommonType & {
    type: "file";
    multiple?: boolean;
    typeFiles?: "images" | "pdf" | "all";
    initialValue?: FileUploaded[];
    onUploadFiles?: (files: FormData) => {};
    value?: FileUploaded[];
};
type FieldInputDate = FieldCommonType & {
    type: "date" | "date_time" | "time";
};
type FieldType = MultipleChoiceType | SingleChoiceType | InputTextNumberType | TitleType | SignatureFieldType | InputTextAnswerType | FileInputType | FieldInputDate;

type CommonProps = {
    onSubmit: (values: unknown) => void;
    onError?: () => void;
    styleContainerForm?: ViewStyle;
    labelButtonSubmit: string;
};

type Props = CommonProps & {
    schemaFields: FieldType[];
};
declare const DynamicForm: React.FC<Props>;

export { DynamicForm, type FieldType, type RequiresTextAnswersType, type SignatureValueType };
